langtools/src/share/classes/com/sun/tools/doclets/formats/html/PackageIndexFrameWriter.java
changeset 1787 1aa079321cd2
parent 10 06bc494ca11e
child 2320 5b8c377175f4
--- a/langtools/src/share/classes/com/sun/tools/doclets/formats/html/PackageIndexFrameWriter.java	Fri Dec 05 21:59:59 2008 -0800
+++ b/langtools/src/share/classes/com/sun/tools/doclets/formats/html/PackageIndexFrameWriter.java	Thu Jan 08 16:26:59 2009 -0800
@@ -87,7 +87,7 @@
     }
 
     /**
      * Print the "-packagesheader" string in bold format, at top of the page,
      * if it is not the empty string.  Otherwise print the "-header" string.
      * Despite the name, there is actually no navigation bar for this page.
      */
@@ -95,9 +95,9 @@
         printTableHeader(true);
         fontSizeStyle("+1", "FrameTitleFont");
         if (configuration.packagesheader.length() > 0) {
-            bold(replaceDocRootDir(configuration.packagesheader));
+            strong(replaceDocRootDir(configuration.packagesheader));
         } else {
-            bold(replaceDocRootDir(configuration.header));
+            strong(replaceDocRootDir(configuration.header));
         }
         fontEnd();
         printTableFooter(true);
@@ -87,7 +87,7 @@
 
     /**
-     * Print the "-packagesheader" string in bold format, at top of the page,
+     * Print the "-packagesheader" string in strong format, at top of the page,
      * if it is not the empty string.  Otherwise print the "-header" string.
      * Despite the name, there is actually no navigation bar for this page.